@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A encoding conversion processor
 
-our $VERSION = '1.111910'; # VERSION
+our $VERSION = '1.111980'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
@@ -20,23 +20,27 @@ has 'input_decoder' => (
     'isa'     => 'Decoder',
     'coerce'  => 1,
     'lazy'    => 1,
-    'default' => sub {
-        sub { $_[0] }
-    },
-    'alias' => 'from',
+    'builder' => '_build_encoder',
+    'alias'   => 'from',
 );
 
+sub _build_encoder {
+    return sub { $_[0] }
+}
+
 has 'output_encoder' => (
     'is'      => 'ro',
     'isa'     => 'Encoder',
     'coerce'  => 1,
     'lazy'    => 1,
-    'default' => sub {
-        sub { $_[0] }
-    },
-    'alias' => 'to',
+    'builder' => '_build_decoder',
+    'alias'   => 'to',
 );
 
+sub _build_decoder {
+    return sub { $_[0] }
+}
+
 sub _build_p {
     my $self = shift;
     return sub {
@@ -61,7 +65,7 @@ DataFlow::Proc::Encoding - A encoding conversion processor
 
 =head1 VERSION
 
-version 1.111910
+version 1.111980
 
 =head1 SEE ALSO
 
